pub enum FileLocation {
RelativeUrl(SmallString, SmallString),
AbsoluteUrl(UrlString),
}Expand description
While a registry file is generally a remote URL, it can also be a file if it comes from a directory flat indexes.
Variants
RelativeUrl(SmallString, SmallString)
URL relative to the base URL.
AbsoluteUrl(UrlString)
Absolute URL.
Implementations
Sourceimpl FileLocation
impl FileLocation
Sourcepub fn new(url: SmallString, base: &SmallString) -> Self
pub fn new(url: SmallString, base: &SmallString) -> Self
Parse a relative or absolute URL on a page with a base URL.
This follows the HTML semantics where a link on a page is resolved relative to the URL of that page.
Sourcepub fn raw_filename(&self) -> &str
pub fn raw_filename(&self) -> &str
Returns the final raw URL path component after removing any query or fragment.
The filename is not percent-decoded.
Sourcepub fn to_url(&self) -> Result<DisplaySafeUrl, ToUrlError>
pub fn to_url(&self) -> Result<DisplaySafeUrl, ToUrlError>
Convert this location to a URL.
A relative URL has its base joined to the path. An absolute URL is
parsed as-is. And a path location is turned into a URL via the file
protocol.
Errors
This returns an error if any of the URL parsing fails, or if, for example, the location is a path and the path isn’t valid UTF-8. (Because URLs must be valid UTF-8.)