pub enum HashPolicy<'a> {
None,
Generate(HashGeneration),
Any(&'a [HashDigest]),
All(&'a [HashDigest]),
}Variants
None
No hash policy is specified.
Generate(HashGeneration)
Hashes should be generated (specifically, a SHA-256 hash), but not validated.
Any(&'a [HashDigest])
Hashes should be validated against a pre-defined list of hashes, and any matching digest is sufficient. If necessary, hashes should be generated so as to ensure that the archive is valid.
All(&'a [HashDigest])
Hashes should be validated against a pre-defined list of hashes, and every digest must match. If necessary, hashes should be generated so as to ensure that the archive is valid.
Implementations
Sourceimpl HashPolicy<'_>
impl HashPolicy<'_>
Sourcepub fn requires_validation(&self) -> bool
pub fn requires_validation(&self) -> bool
Returns true if the hash policy is Any or All.
Sourcepub fn is_generate(&self, dist: &BuiltDist) -> bool
pub fn is_generate(&self, dist: &BuiltDist) -> bool
Returns true if the hash policy indicates that hashes should be generated.
Sourcepub fn algorithms(&self) -> Vec<HashAlgorithm>
pub fn algorithms(&self) -> Vec<HashAlgorithm>
Return the algorithms used in the hash policy.
Sourcepub fn digests(&self) -> &[HashDigest]
pub fn digests(&self) -> &[HashDigest]
Return the digests used in the hash policy.
Sourcepub fn matches(&self, hashes: &[HashDigest]) -> bool
pub fn matches(&self, hashes: &[HashDigest]) -> bool
Returns true if the given hashes satisfy the policy.
Sourcepub fn has_required_algorithms(&self, hashes: &[HashDigest]) -> bool
pub fn has_required_algorithms(&self, hashes: &[HashDigest]) -> bool
Returns true if the given hashes include the algorithms required by the policy.