pub trait Hashed {
// Required method
fn hashes(&self) -> &[HashDigest];
// Provided methods
fn satisfies(&self, hashes: HashPolicy<'_>) -> bool { ... }
fn has_digests(&self, hashes: HashPolicy<'_>) -> bool { ... }
}Required Methods
Sourcefn hashes(&self) -> &[HashDigest]
fn hashes(&self) -> &[HashDigest]
Return the HashDigests for the archive.
Provided Methods
Sourcefn satisfies(&self, hashes: HashPolicy<'_>) -> bool
fn satisfies(&self, hashes: HashPolicy<'_>) -> bool
Returns true if the archive satisfies the given hash policy.
Sourcefn has_digests(&self, hashes: HashPolicy<'_>) -> bool
fn has_digests(&self, hashes: HashPolicy<'_>) -> bool
Returns true if the archive includes the algorithms required by the given hash policy.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".